#
# gtkui.py
#
# Copyright (C) 2008 Zach Tibbitts ('zachtib') <zach@collegegeek.org>
# 
# Deluge is free software.
# 
# You may redistribute it and/or modify it under the terms of the
# GNU General Public License, as published by the Free Software
# Foundation; either version 2 of the License, or (at your option)
# any later version.
# 
# deluge is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with deluge.    If not, write to:
# 	The Free Software Foundation, Inc.,
# 	51 Franklin Street, Fifth Floor
# 	Boston, MA    02110-1301, USA.
#
#    In addition, as a special exception, the copyright holders give
#    permission to link the code of portions of this program with the OpenSSL
#    library.
#    You must obey the GNU General Public License in all respects for all of
#    the code used other than OpenSSL. If you modify file(s) with this
#    exception, you may extend this exception to your version of the file(s),
#    but you are not obligated to do so. If you do not wish to do so, delete
#    this exception statement from your version. If you delete this exception
#    statement from all source files in the program, then also delete it here


import gtk
import pygtk

from deluge.log import LOG as log
from deluge.ui.gtkui.listview import cell_data_size as cell_data_size
from deluge.configmanager import ConfigManager
import deluge.component as component

import ui
import trackers

class GtkUI(ui.UI):
    def enable(self):
        log.debug('Search GtkUI enabled..')
        self.glade = gtk.glade.XML(self.get_resource('search_tab.glade'))
        nb = component.get("MainWindow").main_glade.get_widget('torrent_info')
        self.tab = self.glade.get_widget('search_tab')
        self.label = self.glade.get_widget('search_tab_label')
        self.tab.get_parent().remove(self.tab)
        self.index = nb.append_page(self.tab, self.label)
        self.combo = self.glade.get_widget('tracker_combobox')
        for t in trackers.trackers.keys():
            self.combo.append_text(t)
        self.combo.set_active(0)
        self.text = self.glade.get_widget('search_entry')
        self.text.connect('activate', self.on_search_activate)

        self.liststore = gtk.ListStore(str, str, str, str, long)
        self.listview = self.glade.get_widget('results_listview')
        self.listview.set_rules_hint(True)
        self.listview.connect('row-activated', self.on_add_torrent)
        self.listview.set_model(self.liststore)

        # Torrent Name Column
        column = gtk.TreeViewColumn("Name")
        render = gtk.CellRendererText()
        column.pack_start(render, False)
        column.add_attribute(render, "text", 1)
        column.set_expand(True)
        self.listview.append_column(column)

        # Torrent Seeders Column
        column = gtk.TreeViewColumn("Seeders")
        render = gtk.CellRendererText()
        column.pack_start(render, False)
        column.add_attribute(render, "text", 2)
        self.listview.append_column(column)

        # Torrent Peers Column
        column = gtk.TreeViewColumn("Peers")
        render = gtk.CellRendererText()
        column.pack_start(render, False)
        column.add_attribute(render, "text", 3)
        self.listview.append_column(column)

        # Torrent Size Column
        column = gtk.TreeViewColumn("Size")
        render = gtk.CellRendererText()
        column.pack_start(render, False)
        column.set_cell_data_func(render, cell_data_size, 4)
        self.listview.append_column(column)

        self.search = self.glade.get_widget('search_button')
        self.search.connect('clicked', self.on_search_activate)
        self.add = self.glade.get_widget('add_button')
        self.add.connect('clicked', self.on_add_torrent)

    def disable(self):
        log.debug('Blocklist GtkUI disabled..')

        nb = component.get('MainWindow').main_glade.get_widget('torrent_info')
        nb.remove_page(self.index)

        del self.glade

    def update(self):
        pass

    def on_search_activate(self, widget):
        log.debug('Search clicked')
        data = trackers.search(self.combo.get_active_text(),
                               self.text.get_text())
        self.liststore.clear()
        for item in data:
            self.liststore.append((item['torrent'],
                                   item['title'],
                                   item['seeders'],
                                   item['peers'],
                                   item['size']))

    def on_add_torrent(self, widget, param1=None, param2=None):
        (model, titer) = self.listview.get_selection().get_selected()
        value = model.get_value(titer, 0)
        log.debug(value)
        config = ConfigManager("gtkui.conf")
        component.get("AddTorrentDialog").add_from_url(value)
        component.get("AddTorrentDialog").show(config["focus_add_dialog"])

