#
# trackers.py
#
# Copyright (C) 2008 Zach Tibbitts ('zachtib') <zach@collegegeek.org>
# 
# Deluge is free software.
# 
# You may redistribute it and/or modify it under the terms of the
# GNU General Public License, as published by the Free Software
# Foundation; either version 2 of the License, or (at your option)
# any later version.
# 
# deluge is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with deluge.    If not, write to:
# 	The Free Software Foundation, Inc.,
# 	51 Franklin Street, Fifth Floor
# 	Boston, MA    02110-1301, USA.
#
#    In addition, as a special exception, the copyright holders give
#    permission to link the code of portions of this program with the OpenSSL
#    library.
#    You must obey the GNU General Public License in all respects for all of
#    the code used other than OpenSSL. If you modify file(s) with this
#    exception, you may extend this exception to your version of the file(s),
#    but you are not obligated to do so. If you do not wish to do so, delete
#    this exception statement from your version. If you delete this exception
#    statement from all source files in the program, then also delete it here.

import feedparser
import urllib

def _isohunt_search(query):
    feed = "http://isohunt.com/js/rss/%s" % query
    d = feedparser.parse(feed)
    data = []
    for entry in d['entries']:
        item = {}
        title = entry['title']
        (name, sp) = title.rsplit(None, 1)
        (seeds, peers) = sp.strip('[]').split('/', 1)
        item['title'] = name
        item['torrent'] = entry['enclosures'][0]['href']
        item['seeders'] = seeds
        item['peers'] = peers
        item['size'] = long(entry['enclosures'][0]['length'])
        data.append(item)
    return data

def _mininova_search(query):
    feed = "http://mininova.org/rss/%s" % query
    d = feedparser.parse(feed)
    data = []
    for entry in d['entries']:
        item = {}
        title = entry['title']
        (name, sp) = title.rsplit(None, 1)
        (seeds, peers) = sp.strip('()').split('/', 1)
        item['title'] = name
        item['torrent'] = entry['enclosures'][0]['href']
        item['seeders'] = seeds.strip('S')
        item['peers'] = peers.strip('L')
        item['size'] = long(entry['enclosures'][0]['length'])
        data.append(item)
    return data

def _pirate_search(query):
    feed = "http://rss.thepiratebay.org/tag/%s" % query
    d = feedparser.parse(feed)
    data = []
    for entry in d['entries']:
        item = {}
        item['title'] = entry['title']
        item['torrent'] = entry['links'][0]['href']
        item['seeders'] = "N/A"
        item['peers'] = "N/A"
        item['size'] = 0
        data.append(item)
    return data


trackers = {'Isohunt': _isohunt_search,
            'Mininova': _mininova_search,
           #'The Pirate Bay': _pirate_search
            }

def search(tracker, query):
    return trackers[tracker](urllib.pathname2url(query))
